<?php
/**
 * Plugin Name: Customise Maximum Bookings Per Slot for All Week
 * Plugin URI: https://pluginhive.com/
 * Description: An Add-on for PluginHive Woocommerce Booking and Appointments plugin to set maximum number of bookings per slot for All Week based on custom start and end time.
 * Version: 1.0.1
 * Author: pluginhive
 * Author URI: https://pluginhive.com
 * Text Domain: bookings-and-appointments-for-woocommerce
 */

// Ticket--https://pluginhive.zendesk.com/agent/tickets/113709

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! defined( 'PH_BOOKINGS_CUSTOMISE_MAX_BOOKING_FOR_ALL_WEEK_PLUGIN_FILE' ) )
	define( 'PH_BOOKINGS_CUSTOMISE_MAX_BOOKING_FOR_ALL_WEEK_PLUGIN_FILE', __FILE__ );

	define( 'PH_MAX_BOOKINGS_SETTING_IDs', 'ph_booking_customize_maximum_booking_per_slot_week' );

	function ph_bookings_activation_check_for_customise_maximum_booking_per_slot_week_addon(){
		if ( !is_plugin_active('ph-bookings-appointments-woocommerce-premium/ph-bookings-appointments-woocommerce-premium.php') ){
			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the Customise Maximum Bookings Per Slot for All Week Plugin without activating Bookings and Appointments For WooCommerce Premium Plugin. Kindly activate <b>Bookings and Appointments For WooCommerce Premium Plugin</b> and then try again", "bookings-and-appointments-for-woocommerce" ), "", array('back_link' => 1 ));
		}
	 }
     
     register_activation_hook( __FILE__, 'ph_bookings_activation_check_for_customise_maximum_booking_per_slot_week_addon' );
     
	 //check if woocommerce exists
	 if ( !class_exists( 'woocommerce' ) || !class_exists('phive_booking_initialze_premium') ) {
		add_action( 'admin_init', 'Ph_Bookings_Customise_Maximum_Bookings_Per_Slot_week_deactivate' );
		if ( ! function_exists( 'Ph_Bookings_Customise_Maximum_Bookings_Per_Slot_week_deactivate' ) ) {
			function Ph_Bookings_Customise_Maximum_Bookings_Per_Slot_week_deactivate() {
				if ( !class_exists( 'woocommerce' ) || !class_exists('phive_booking_initialze_premium') ){
					deactivate_plugins( plugin_basename( __FILE__ ) );
					wp_safe_redirect( admin_url('plugins.php') );
				}
			}
		}
	 }

	 
if( ! class_exists('Ph_Bookings_Customise_Maximum_Bookings_Week_Class') ) {
	class Ph_Bookings_Customise_Maximum_Bookings_Week_Class {

		/**
		 * Constructor
		 */
		public function __construct() {

			add_filter('add_time_range_type', array($this, 'ph_bookings_modify_total_booking_availability'), 10, 7);			
			add_action('allweek_jquery',array( $this, 'allweek_jquery' ));
			add_action('add_option_to_select',array($this, 'add_option_to_select'),10,1);
			add_action('add_option_to_div_from',array($this, 'add_option_to_div_from'),10,1);
			add_action('add_option_to_div_to',array($this, 'add_option_to_div_to'),10,1);
			add_filter('display_settings',array($this, 'display_settings'),10,4);
			
			add_filter('ph_time_range_type_availability_modified', array($this, 'ph_time_range_type_availability_modified'), 10,1);

			$this->availability_modified = 0;

			// 96421
			add_filter('ph_modify_max_booking_all_week_addon', array($this, 'ph_modify_max_booking_all_week_addon'), 10, 7);
		}

		public function ph_bookings_modify_total_booking_availability($availability,$product_id,$value, $date,$found,$asset_id,$rules)
		{
			
			if($found === false)
			{
				$found = 0;	
			}
	
			if (!empty($value['from_time_all_week']) && !empty($value['to_time_all_week'])) 
			{
				$from_time = (isset($value['from_time_all_week']) && !empty($value['from_time_all_week'])) ? $value['from_time_all_week'] : '00:00';
				$to_time = (isset($value['to_time_all_week']) && !empty($value['to_time_all_week'])) ? $value['to_time_all_week'] : '23:59';
				
				$from_date = date('Y-m-d ', $date).' '.$from_time;
				$to_date = date('Y-m-d ', $date).' '.$to_time;

				if (strtotime(date('Y-m-d  H:i', $date)) >= strtotime($from_date) && strtotime(date('Y-m-d  H:i', $date)) <= strtotime($to_date)) 
				{
					if(!empty($value['max_booking']))
					{
						$availability = $value['max_booking']-$found;
						$found = false;
						$this->availability_modified = 1;
						$availability = max( 0, $availability );
						return $availability;
					}
				}
				
			}
				
			return $availability;		
		}
		
		public function ph_time_range_type_availability_modified($availability_modified = 0)
		{
			$availability_modified = $this->availability_modified;
			$this->availability_modified = 0;
			return $availability_modified;
		}

		public function ph_modify_max_booking_all_week_addon($allowd_per_slot, $product_id, $asset_id, $date, $booking_count, $rules, $value)
		{
			if (!empty($value['from_time_all_week']) && !empty($value['to_time_all_week'])) 
			{
				$from_time = (isset($value['from_time_all_week']) && !empty($value['from_time_all_week'])) ? $value['from_time_all_week'] : '00:00';
				$to_time = (isset($value['to_time_all_week']) && !empty($value['to_time_all_week'])) ? $value['to_time_all_week'] : '23:59';
				
				$from_date = date('Y-m-d ', $date).' '.$from_time;
				$to_date = date('Y-m-d ', $date).' '.$to_time;

				if (strtotime(date('Y-m-d  H:i', $date)) >= strtotime($from_date) && strtotime(date('Y-m-d  H:i', $date)) <= strtotime($to_date)) 
				{
					if(!empty($value['max_booking']))
					{
						$allowd_per_slot = max(0, $value['max_booking']);
						return $allowd_per_slot;
					}
				}
				
			}

			return $allowd_per_slot;
		}
		
		public function allweek_jquery(){
			?>
				$(row).find('.availability_by_all_week').hide();
				if ( value == 'all_week' ) {
					$(row).find('.availability_by_all_week').show();
				}
			
			<?php
		}
		public function add_option_to_select($rule){
			?>
				<option value="all_week" <?php echo ( isset($rule['range_type'] ) && $rule['range_type']=='all_week') ? 'selected="selected"' : '';?>><?php _e('Time Range (all week) ','bookings-and-appointments-for-woocommerce')?></option>
			<?php
		}
		public function add_option_to_div_from($rule){
			?>
				<div class="availability_by_all_week" style="display: <?php echo ( isset($rule['range_type'] ) && $rule['range_type']=='all_week' )  ? 'block;' : 'none;';?>">
					<input type="time" class="ph_booking_from_time_all_week" name="from_time_all_week[]" value="<?php echo isset($rule['from_time_all_week']) ? $rule['from_time_all_week'] : '';?>">
				</div>
			<?php
		}
		public function add_option_to_div_to($rule){
			?>
				<div class="availability_by_all_week" style="display: <?php echo ( isset($rule['range_type'] ) && $rule['range_type']=='all_week' ) ? 'block;' : 'none;';?>">
					<input type="time" class="ph_booking_to_time_all_week" name="to_time_all_week[]" value="<?php echo isset($rule['to_time_all_week']) ? $rule['to_time_all_week'] : '';?>">
				</div>
			<?php
		}
		public function display_settings($settings,$key,$type,$product_id){

			$settings['from_time_all_week'] = $_POST['from_time_all_week'][$key];
			$settings['to_time_all_week'] = $_POST['to_time_all_week'][$key];
			
			return $settings;
		}
	}
}
new Ph_Bookings_Customise_Maximum_Bookings_Week_Class();